*****************************************************************************************
* FILE NAME:     SASOUT23_LLCP.SAS                                                      *
* DESCRIPTION:   THIS PROGRAM CONVERTS A STATES ASCII DATAFILE OF COMPLETES LOCATED AT  *
*                <DATAIN> FILEREF, INTO A SAS DATABASE STORED AT <DATAOUT> LIBREF       *
* REFERENCES:                                                                           *
* INPUT       DATAIN           FILEREF OF ASCII DATAFILE OF COMPLETES                   *
* FORMATS     FORMATS.SAS7BCAT      SAS FORMATS DATABASE                                *
* OUTPUT      DATAOUT.SASDATA  SAS DATABASE VERSION OF ASCII DATA AS SPECIFIED IN       *
*                              <DATAIN> FILEREF                                         *
* UPDATED - 07/31/2024                                                                  *
*****************************************************************************************;
********************************
* Clear Output and Log Windows *
********************************;
DM OUTPUT 'clear' continue;
DM LOG    'clear' continue;
**********************************
* DEFINE SAS ENVIRONMENT OPTIONS *
**********************************;
OPTIONS PAGENO=1 NOFMTERR;
***************************************
* CLEAR EXISTING TITLES AND FOOTNOTES *
***************************************;
TITLE ;
FOOTNOTE ;
RUN ;
******************************************************************
* INSTRUCTIONS:                                                  *
* SPECIFY PATH OF WHERE ASCII DATAFILE IS STORED                 *
* SPECIFY PATH OF WHERE SAS DATASET IS TO BE STORED              *
* SPECIFY PATH OF WHERE SAS FORMAT LIBRARY IS STORED             *
* SPECIFY PATH OF WHERE THE FORMAT ASSIGNMET STATEMENT IS STORED *
******************************************************************;

*FILENAME DATAIN '<PATH OF INPUT STATE ASCII DATAFILE OF COMPLETES>' LRECL = 2111 ;
*****************************************************************************
* EXAMPLE:                                                                  *
*       FILENAME DATAIN 'C:\BRFSS\2023\LLCP2023.ASC' LRECL = 2111           *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD FILENAME AND      *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE FILENAME STATEMENT                                         *
*****************************************************************************;

*LIBNAME DATAOUT V7 '<PATH OF PERMANENTLY STORED SAS DATASET VERSION OF DATAIN FILEREF>'  ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          LIBNAME DATAOUT 'C:\'                                            *
*          A SAS DATABASE WILL BE STORED AT C:\SASDATA.sas7bdat             *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD LIBNAME AND       *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE LIBNAME STATEMENT                                          *
*****************************************************************************;

*LIBNAME LIBRARY '<PATH OF STORED SAS FORMAT23.SAS7BCAT>' ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          LIBNAME LIBRARY 'C:\'                                            *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD LIBNAME AND       *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE LIBNAME STATEMENT                                          *
*****************************************************************************;

*FILENAME FORMATIN '<PATH OF FORMAT ASSIGNMENT STATEMENT>' ;
*****************************************************************************
* EXAMPLE:                                                                  *
*          FILENAME FORMATIN 'C:\FORMATSTATEMENT.SAS'                       *
* NOTE: MAKE SURE THE ASTERISK IS REMOVED BEFORE THE WORD FILENAME AND      *
*       MAKE SURE THAT THE GREATER THAN AND LESS THAN SIGNS < > ARE REMOVED *
*       FROM THE FILENAME STATEMENT                                         *
*****************************************************************************;

DATA DATAOUT.SASDATA ;
INFILE DATAIN MISSOVER ;
INPUT
_STATE        1-2                     /* Record Identification */
FMONTH        17-18
IDATE         $19-26
IMONTH        $19-20
IDAY          $21-22
IYEAR         $23-26
DISPCODE      32-35
SEQNO         $36-45
_PSU          36-45
CTELENM1      63                      /* Land Line Introduction */
PVTRESD1      64
COLGHOUS      65
STATERE1      66
CELPHON1      67
LADULT1       68
NUMADULT      69-70
RESPSLC1      71
LANDSEX2      72
LNDSXBRT      73
SAFETIME      74                      /* Cell Phone Introduction */
CTELNUM1      75
CELLFON5      76
CADULT1       77
CELLSEX2      78
CELSXBRT      79
PVTRESD3      80
CCLGHOUS      81
CSTATE1       82
LANDLINE      85
HHADULT       86-87
SEXVAR        88                      /* Respondent Sex */
GENHLTH       101                     /* Section 1: Health Status */
PHYSHLTH      102-103                 /* Section 2: Healthy Days */
MENTHLTH      104-105
POORHLTH      106-107
PRIMINS1      108-109                 /* Section 3: Health Care Access */
PERSDOC3      110
MEDCOST1      111
CHECKUP1      112
EXERANY2      113                     /* Section 4: Exercise (Physical Activity) */
EXRACT12      114-115
EXEROFT1      116-118
EXERHMM1      119-121
EXRACT22      122-123
EXEROFT2      124-126
EXERHMM2      127-129
STRENGTH      130-132
BPHIGH6       133                     /* Section 5: Hypertension Awareness */
BPMEDS1       134
CHOLCHK3      135                     /* Section 6: Cholesterol Awareness */
TOLDHI3       136
CHOLMED3      137
CVDINFR4      138                     /* Section 7: Chronic Health Conditions */
CVDCRHD4      139
CVDSTRK3      140
ASTHMA3       141
ASTHNOW       142
CHCSCNC1      143
CHCOCNC1      144
CHCCOPD3      145
ADDEPEV3      146
CHCKDNY2      147
HAVARTH4      148
DIABETE4      149
DIABAGE4      150-151
MARITAL       186
EDUCA         187
RENTHOM1      188
NUMHHOL4      197
NUMPHON4      198
CPDEMO1C      199
VETERAN3      200
EMPLOY1       201
CHILDREN      202-203
INCOME3       204-205
PREGNANT      206
WEIGHT2       207-210
HEIGHT3       211-214
DEAF          215                     /* Section 9: Disability */
BLIND         216
DECIDE        217
DIFFWALK      218
DIFFDRES      219
DIFFALON      220
FALL12MN      221-222                 /* Section 10: Falls */
FALLINJ5      223-224
SMOKE100      225                     /* Section 11: Tobacco Use */
SMOKDAY2      226
USENOW3       227
ECIGNOW2      228
ALCDAY4       229-231                 /* Section 12: Alcohol Consumption */
AVEDRNK3      232-233
DRNK3GE5      234-235
MAXDRNKS      236-237
FLUSHOT7      238                     /* Section 13: Immunization */
FLSHTMY3      239-244
PNEUVAC4      245
SHINGLE2      246
HIVTST7       247                     /* Section 14: HIV/AIDS */
HIVTSTD3      248-253
SEATBELT      254                     /* Section 15: Seatbelt Use and Drinking and Driving */
DRNKDRI2      255-256
COVIDPO1      257                     /* Section 16: Long-term COVID Effects */
COVIDSM1      258
COVIDACT      259
PDIABTS1      260                     /* Module 1: Pre-Diabetes */
PREDIAB2      261
DIABTYPE      262                     /* Module 2: Diabetes */
INSULIN1      263
CHKHEMO3      264-265
EYEEXAM1      266
DIABEYE1      267
DIABEDU1      268
FEETSORE      269
ARTHEXER      270                     /* Module 3: Arthritis */
ARTHEDU       271
LMTJOIN3      272
ARTHDIS2      273
JOINPAI2      274-275
LCSFIRST      276-278                 /* Module 4: Lung Cancer Screening */
LCSLAST       279-281
LCSNUMCG      282-284
LCSCTSC1      285
LCSSCNCR      286
LCSCTWHN      287
HADMAM        288                     /* Module 5: Breast and Cervical Cancer Screening */
HOWLONG       289
CERVSCRN      290
CRVCLCNC      291
CRVCLPAP      292
CRVCLHPV      293
HADHYST2      294
PSATEST1      295                     /* Module 6: Prostate Cancer Screening */
PSATIME1      296
PCPSARS2      297
PSASUGS1      298
PCSTALK2      299
HADSIGM4      300                     /* Module 7: Colorectal Cancer Screening */
COLNSIGM      301
COLNTES1      302
SIGMTES1      303
LASTSIG4      304
COLNCNCR      305
VIRCOLO1      306
VCLNTES2      307
SMALSTOL      308
STOLTEST      309
STOOLDN2      310
BLDSTFIT      311
SDNATES1      312
CNCRDIFF      313                     /* Module 8: Cancer Survivorship: Type of Cancer */
CNCRAGE       314-315
CNCRTYP2      316-317
CSRVTRT3      318                     /* Module 9: Cancer Survivorship: Course of Treatment */
CSRVDOC1      319-320
CSRVSUM       321
CSRVRTRN      322
CSRVINST      323
CSRVINSR      324
CSRVDEIN      325
CSRVCLIN      326
CSRVPAIN      327                     /* Module 10: Cancer Survivorship: Pain Management */
CSRVCTL2      328
INDORTAN      329-331                 /* Module 11: Indoor Tanning */
NUMBURN3      332-334                 /* Module 12: Excess Sun Exposure */
SUNPRTCT      335
WKDAYOUT      336-337
WKENDOUT      338-339
CIMEMLO1      340                     /* Module 13: Cognitive Decline */
CDWORRY       341
CDDISCU1      342
CDHOUS1       343
CDSOCIA1      344
CAREGIV1      345                     /* Module 14: Caregiver */
CRGVREL4      346-347
CRGVLNG1      348
CRGVHRS1      349
CRGVPRB3      350-351
CRGVALZD      352
CRGVPER1      353
CRGVHOU1      354
CRGVEXPT      355
LASTSMK2      356-357                 /* Module 15: Tobacco Cessation */
STOPSMK2      358
MENTCIGS      359                     /* Module 16: Other Tobacco Use */
MENTECIG      360
HEATTBCO      361
FIREARM5      362                     /* Module 17: Firearm Safety */
GUNLOAD       363
LOADULK2      364
HASYMP1       565                     /* Module 19: Heart Attack and Stroke */
HASYMP2       566
HASYMP3       567
HASYMP4       568
HASYMP5       569
HASYMP6       570
STRSYMP1      571
STRSYMP2      572
STRSYMP3      573
STRSYMP4      574
STRSYMP5      575
STRSYMP6      576
FIRSTAID      577
ASPIRIN       578                     /* Module 20: Aspirin for CVD Prevention */
BIRTHSEX      579                     /* Module 21: Sex at Birth */
SOMALE        580                     /* Module 22: Sexual Orientation and Gender Identity (SOGI) */
SOFEMALE      581
TRNSGNDR      582
MARIJAN1      583-584                 /* Module 23: Marijuana Use */
MARJSMOK      585
MARJEAT       586
MARJVAPE      587
MARJDAB       588
MARJOTHR      589
USEMRJN4      590
ACEDEPRS      591                     /* Module 24: Adverse Childhood Experiences */
ACEDRINK      592
ACEDRUGS      593
ACEPRISN      594
ACEDIVRC      595
ACEPUNCH      596
ACEHURT1      597
ACESWEAR      598
ACETOUCH      599
ACETTHEM      600
ACEHVSEX      601
ACEADSAF      602
ACEADNED      603
IMFVPLA4      604-605                 /* Module 25: Place of Flu Vaccination */
HPVADVC4      606                     /* Module 26: HPV Vaccination */
HPVADSHT      607-608
TETANUS1      609                     /* Module 27: Tetanus Diphtheria (Tdap) (Adults) */
COVIDVA1      610                     /* Module 28: COVID Vaccination */
COVACGE1      611
COVIDNU2      612
LSATISFY      613                     /* Module 29: Social Determinants of Health and Health Equity (SDOH/HE) */
EMTSUPRT      614
SDLONELY      615
SDHEMPLY      616
FOODSTMP      617
SDHFOOD1      618
SDHBILLS      619
SDHUTILS      620
SDHTRNSP      621
SDHSTRE1      622
RRCLASS3      623-624                 /* Module 30: Reactions to Race */
RRCOGNT2      625
RRTREAT       626
RRATWRK2      627
RRHCARE4      628
RRPHYSM2      629
RCSGEND1      636
RCSXBRTH      637
RCSRLTN2      670
CASTHDX2      671                     /* Module 32: Childhood Asthma Prevalence */
CASTHNO2      672
QSTVER        677-678                 /* Questionnaire Version */
QSTLANG       679-680                 /* Questionnaire Language */
_METSTAT      1402
_URBSTAT      1403
MSCODE        1409
_STSTR        1410-1415
_STRWT        1416-1425
_RAWRAKE      1446-1455
_WT2RAKE      1456-1465
_IMPRACE      1471-1472
_CHISPNC      1482                    /* Child Demographic Variables */
_CRACE1       1539-1540
CAGEG         1567
_CLLCPWT      1583-1592
_DUALUSE      1680
_DUALCOR      1681-1690
_LLCPWT2      1691-1700
_LLCPWT       1749-1758
_RFHLTH       1897                    /* Section 1: Calculated Variables */
_PHYS14D      1898                    /* Section 2: Calculated Variables */
_MENT14D      1899
_HLTHPL1      1900                    /* Section 3: Calculated Variables */
_HCVU653      1901
_TOTINDA      1902                    /* Section 4: Calculated Variables */
METVL12_      1903-1905
METVL22_      1906-1908
MAXVO21_      1909-1913
FC601_        1914-1918
ACTIN13_      1919
ACTIN23_      1920
PADUR1_       1921-1923
PADUR2_       1924-1926
PAFREQ1_      1927-1931
PAFREQ2_      1932-1936
_MINAC12      1937-1941
_MINAC22      1942-1946
STRFREQ_      1947-1951
PAMISS3_      1952
PAMIN13_      1953-1957
PAMIN23_      1958-1962
PA3MIN_       1963-1967
PAVIG13_      1968-1972
PAVIG23_      1973-1977
PA3VIGM_      1978-1982
_PACAT3       1983
_PAINDX3      1984
_PA150R4      1985
_PA300R4      1986
_PA30023      1987
_PASTRNG      1988
_PAREC3       1989
_PASTAE3      1990
_RFHYPE6      1991                    /* Section 5: Calculated Variables */
_CHOLCH3      1992                    /* Section 6: Calculated Variables */
_RFCHOL3      1993
_MICHD        1994                    /* Section 7: Calculated Variables */
_LTASTH1      1995
_CASTHM1      1996
_ASTHMS1      1997
_DRDXAR2      1998
_MRACE1       2055-2056
_HISPANC      2059
_RACE         2060
_RACEG21      2061
_RACEGR3      2062
_RACEPRV      2063
_SEX          2064
_AGEG5YR      2065-2066
_AGE65YR      2067
_AGE80        2068-2069
_AGE_G        2070
HTIN4         2071-2073
HTM4          2074-2076
WTKG3         2077-2081
_BMI5         2082-2085
_BMI5CAT      2086
_RFBMI5       2087
_CHLDCNT      2088
_EDUCAG       2089
_INCOMG1      2090
_SMOKER3      2091                    /* Section 11: Calculated Variables */
_RFSMOK3      2092
_CURECI2      2093
DRNKANY6      2094                    /* Section 12: Calculated Variables */
DROCDY4_      2095-2097
_RFBING6      2098
_DRNKWK2      2099-2103
_RFDRHV8      2104
_FLSHOT7      2105                    /* Section 13: Calculated Variables */
_PNEUMO3      2106
_AIDTST4      2107                    /* Section 14: Calculated Variables */
_RFSEAT2      2108                    /* Section 15: Calculated Variables */
_RFSEAT3      2109
_DRNKDRV      2110
;
*****************************************************************
* TO INCLUDE THE FORMAT ASSIGNEMT STATEMENT REMOVE THE ASTERISK *
* FROM THE BEGINNING OF THE FOLLOWING LINE                      *
*****************************************************************;
* %INCLUDE FORMATIN ;
*************************************************
* THIS SECTION CREATES LABELS FOR THE VARIABLES *
*************************************************;
Label
ACEADNED = 'DID AN ADULT MAKE SURE BASIC NEEDS WERE MET'
ACEADSAF = 'DID AN ADULT MAKE YOU FEEL SAFE AND PROTECTED'
ACEDEPRS = 'LIVE WITH ANYONE DEPRESSED, MENTALLY ILL, OR SUICIDAL?'
ACEDIVRC = 'WERE YOUR PARENTS DIVORCED/SEPERATED?'
ACEDRINK = 'LIVE WITH A PROBLEM DRINKER/ALCOHOLIC?'
ACEDRUGS = 'LIVE WITH ANYONE WHO USED ILLEGAL DRUGS OR ABUSED PRESCRIPTIONS?'
ACEHURT1 = 'HOW OFTEN DID A PARENT PHYSICALLY HURT YOU IN ANY WAY?'
ACEHVSEX = 'HOW OFTEN DID ANYONE EVER FORCE YOU TO HAVE SEX?'
ACEPRISN = 'LIVE WITH ANYONE WHO SERVED TIME IN PRISON OR JAIL?'
ACEPUNCH = 'HOW OFTEN DID YOUR PARENTS BEAT EACH OTHER UP?'
ACESWEAR = 'HOW OFTEN DID A PARENT SWEAR AT YOU?'
ACETOUCH = 'HOW OFTEN DID ANYONE EVER TOUCH YOU SEXUALLY?'
ACETTHEM = 'HOW OFTEN DID ANYONE MAKE YOU TOUCH THEM SEXUALLY?'
ACTIN13_ = 'ESTIMATED ACTIVITY INTENSITY FOR FIRST ACTIVITY'
ACTIN23_ = 'ESTIMATED ACTIVITY INTENSITY FOR SECOND ACTIVITY'
ADDEPEV3 = '(EVER TOLD) YOU HAD A DEPRESSIVE DISORDER'
ALCDAY4 = 'DAYS IN PAST 30 HAD ALCOHOLIC BEVERAGE'
ARTHDIS2 = 'DOES ARTHRITIS AFFECT WHETHER YOU WORK'
ARTHEDU = 'EVER TAKEN CLASS IN MANAGING ARTHRITIS OR JOINT SYMPTOMS'
ARTHEXER = 'DR. SUGGEST USE OF PHYSICAL ACTIVITY OR EXERCISE FOR ARTHRITIS OR JOINT SYMPTOMS'
ASPIRIN = 'HOW OFTEN DO YOU TAKE AN ASPIRIN'
ASTHMA3 = 'EVER TOLD HAD ASTHMA'
ASTHNOW = 'STILL HAVE ASTHMA'
AVEDRNK3 = 'AVG ALCOHOLIC DRINKS PER DAY IN PAST 30'
BIRTHSEX = 'ARE YOU MALE OR FEMALE?'
BLDSTFIT = 'WAS TEST PART OF COLOGUARD TEST?'
BLIND = 'BLIND OR DIFFICULTY SEEING'
BPHIGH6 = 'EVER TOLD BLOOD PRESSURE HIGH'
BPMEDS1 = 'CURRENTLY TAKING PRESCRIPTION BLOOD PRESSURE MEDICATION'
CADULT1 = 'ARE YOU 18 YEARS OF AGE OR OLDER?'
CAGEG = 'FOUR LEVEL CHILD AGE'
CAREGIV1 = 'PROVIDED REGULAR CARE FOR FAMILY OR FRIEND'
CASTHDX2 = 'HLTH PRO EVER SAID CHILD HAS ASTHMA'
CASTHNO2 = 'CHILD STILL HAVE ASTHMA?'
CCLGHOUS = 'DO YOU LIVE IN COLLEGE HOUSING?'
CDDISCU1 = 'HAVE YOU DISCUSSED YOUR DIFFICULTIES WITH THINKING WITH A HEALTH CARE PROVIDER?'
CDHOUS1 = 'GIVEN UP DAY-TO-DAY CHORES DUE TO DIFFICULTIES WITH THINKING OR MEMORY'
CDSOCIA1 = 'DOES DIFFICULTIES WITH THINKING OR MEMORY INTERFERE WITH WORK OR SOCIAL ACTIVITIES'
CDWORRY = 'ARE YOU WORRIED ABOUT THESE DIFFICULTIES WITH THINKING OR MEMORY?'
CELLFON5 = 'IS THIS A CELL PHONE?'
CELLSEX2 = 'ARE YOU MALE OR FEMALE?'
CELPHON1 = 'CELLULAR TELEPHONE'
CELSXBRT = 'WHAT WAS YOUR SEX AT BIRTH?'
CERVSCRN = 'HAVE YOU EVER HAD A CERVICAL CANCER SCREENING TEST?'
CHCCOPD3 = 'EVER TOLD YOU HAD C.O.P.D. EMPHYSEMA OR CHRONIC BRONCHITIS?'
CHCKDNY2 = 'EVER TOLD YOU HAVE KIDNEY DISEASE?'
CHCOCNC1 = '(EVER TOLD) (YOU HAD) MELANOMA OR ANY OTHER TYPES OF CANCER?'
CHCSCNC1 = '(EVER TOLD) (YOU HAD) SKIN CANCER THAT IS NOT MELANOMA?'
CHECKUP1 = 'LENGTH OF TIME SINCE LAST ROUTINE CHECKUP'
CHILDREN = 'NUMBER OF CHILDREN IN HOUSEHOLD'
CHKHEMO3 = 'TIMES CHECKED FOR GLYCOSYLATED HEMOGLOBIN'
CHOLCHK3 = 'HOW LONG SINCE CHOLESTEROL CHECKED'
CHOLMED3 = 'CURRENTLY TAKING MEDICINE FOR HIGH CHOLESTEROL'
CIMEMLO1 = 'HAVE YOU EXPERIENCED DIFFICULTIES WITH THINKING OR MEMORY THAT IS HAPPENING MORE OFTEN OR IS GETTING WORSE?'
CNCRAGE = 'AGE TOLD HAD CANCER'
CNCRDIFF = 'HOW MANY TYPES OF CANCER?'
CNCRTYP2 = 'TYPE OF CANCER'
COLGHOUS = 'DO YOU LIVE IN COLLEGE HOUSING?'
COLNCNCR = 'EVER HAD ANY OTHER KIND OF TEST FOR COLORECTAL CANCER'
COLNSIGM = 'EVER HAD A COLONOSCOPY, SIGMOIDOSCOPY, OR BOTH'
COLNTES1 = 'HOW LONG HAS IT BEEN SINCE YOU HAD COLONOSCOPY?'
COVACGE1 = 'GOING TO GET VACCINATED'
COVIDACT = 'DO LONG-TERM SYMPTOMS REDUCE ABILITY TO CARRY OUT ACTIVITIES?'
COVIDNU2 = 'NUMBER OF COVID-19 VACCINATIONS RECEIVED'
COVIDPO1 = 'HAVE YOU EVER TESTED POSITIVE FOR COVID-19?'
COVIDSM1 = 'DO YOU CURRENTLY HAVE COVID-19 SYMPTOMS?'
COVIDVA1 = 'RECEIVED AT LEAST ONE COVID-19 VACCINATION'
CPDEMO1C = 'DO YOU HAVE A CELL PHONE FOR YOUR PERSONAL USE?'
CRGVALZD = 'DOES PERSON BEING CARED FOR HAVE ALZHEIMERS DISEASE?'
CRGVEXPT = 'DO YOU EXPECT TO HAVE A RELATIVE YOU WILL NEED TO PROVIDE CARE FOR?'
CRGVHOU1 = 'MANAGED HOUSEHOLD TASKS'
CRGVHRS1 = 'HOW MANY HOURS DO YOU PROVIDE CARE FOR PERSON?'
CRGVLNG1 = 'HOW LONG PROVIDED CARE FOR PERSON.'
CRGVPER1 = 'MANAGED PERSONAL CARE'
CRGVPRB3 = 'WHAT IS THE MAJOR HEALTH PROBLEM, ILLNESS, DISABILITY FOR CARE FOR PERSON?'
CRGVREL4 = 'RELATIONSHIP OF PERSON TO WHOM YOU ARE GIVING CARE?'
CRVCLCNC = 'TIME SINCE LAST CERVICAL CANCER SCREENING TEST'
CRVCLHPV = 'HAVE AN H.P.V. TEST AND RECENT CERVICAL CANCER SCREENING'
CRVCLPAP = 'HAVE A PAP TEST AND RECENT CERVICAL CANCER SCREENING'
CSRVCLIN = 'PARTICIPATE IN CLINICAL TRIAL AS PART OF CANCER TREATMENT?'
CSRVCTL2 = 'IS PAIN UNDER CONTROL?'
CSRVDEIN = 'EVER DENIED INSURANCE COVERAGE BECAUSE OF YOUR CANCER?'
CSRVDOC1 = 'WHAT TYPE OF DOCTOR PROVIDES MAJORITY OF YOUR CARE'
CSRVINSR = 'DID HEALTH INSURANCE PAY FOR ALL OF YOUR CANCER TREATMENT'
CSRVINST = 'INSTRUCTIONS WRITTEN OR PRINTED'
CSRVPAIN = 'CURRENTLY HAVE PHYSICAL PAIN FROM CANCER OR TREATMENT?'
CSRVRTRN = 'EVER RECEIVE INSTRUCTIONS FROM A DOCTOR FOR FOLLOW-UP CHECK-UPS'
CSRVSUM = 'DID YOU RECEIVE A SUMMARY OF CANCER TREATMENTS RECEIVED'
CSRVTRT3 = 'CURRENTLY RECEIVING TREATMENT FOR CANCER'
CSTATE1 = 'DO YOU CURRENTLY LIVE IN  ____(STATE)____?'
CTELENM1 = 'CORRECT TELEPHONE NUMBER?'
CTELNUM1 = 'CORRECT PHONE NUMBER?'
CVDCRHD4 = 'EVER DIAGNOSED WITH ANGINA OR CORONARY HEART DISEASE'
CVDINFR4 = 'EVER DIAGNOSED WITH HEART ATTACK'
CVDSTRK3 = 'EVER DIAGNOSED WITH A STROKE'
DEAF = 'ARE YOU DEAF OR DO YOU HAVE SERIOUS DIFFICULTY HEARING?'
DECIDE = 'DIFFICULTY CONCENTRATING OR REMEMBERING'
DIABAGE4 = 'AGE WHEN FIRST TOLD YOU HAD DIABETES'
DIABEDU1 = 'WHEN WAS THE LAST TIME YOU TOOK A COURSE OR CLASS IN HOW TO MANAGE YOUR DIABETES?'
DIABETE4 = '(EVER TOLD) YOU HAD DIABETES'
DIABEYE1 = 'WHEN WAS THE LAST TIME A THEY TOOK A PHOTO OF THE BACK OF YOUR EYE?'
DIABTYPE = 'WHAT TYPE OF DIABETES DO YOU HAVE?'
DIFFALON = 'DIFFICULTY DOING ERRANDS ALONE'
DIFFDRES = 'DIFFICULTY DRESSING OR BATHING'
DIFFWALK = 'DIFFICULTY WALKING OR CLIMBING STAIRS'
DISPCODE = 'FINAL DISPOSITION'
DRNK3GE5 = 'BINGE DRINKING'
DRNKANY6 = 'DRINK ANY ALCOHOLIC BEVERAGES IN PAST 30 DAYS'
DRNKDRI2 = 'DID YOU DRIVE AFTER HAVING TOO MUCH TO DRINK IN THE PAST 30 DAYS?'
DROCDY4_ = 'COMPUTED DRINK-OCCASIONS-PER-DAY'
ECIGNOW2 = 'DO YOU NOW USE E-CIGARETTES, OR VAPING PRODUCTS EVERY DAY, SOME DAYS, OR NOT AT ALL?'
EDUCA = 'EDUCATION LEVEL'
EMPLOY1 = 'EMPLOYMENT STATUS'
EMTSUPRT = 'HOW OFTEN GET EMOTIONAL SUPPORT NEEDED'
EXERANY2 = 'EXERCISE IN PAST 30 DAYS'
EXERHMM1 = 'MINUTES OR HOURS WALKING, RUNNING, JOGGING, OR SWIMMING'
EXERHMM2 = 'MINUTES OR HOURS WALKING, RUNNING, JOGGING, OR SWIMMING'
EXEROFT1 = 'HOW MANY TIMES WALKING, RUNNING, JOGGING, OR SWIMMING'
EXEROFT2 = 'HOW MANY TIMES WALKING, RUNNING, JOGGING, OR SWIMMING'
EXRACT12 = 'TYPE OF PHYSICAL ACTIVITY'
EXRACT22 = 'OTHER TYPE OF PHYSICAL ACTIVITY GIVING MOST EXERCISE DURING PAST MONTH'
EYEEXAM1 = 'LAST EYE EXAM WHERE PUPILS WERE DILATED'
FALL12MN = 'HAD FALL PAST TWELVE MONTHS'
FALLINJ5 = 'INJURED IN FALL OR HAD TO SEE DOCTOR'
FC601_ = 'ESTIMATED FUNCTIONAL CAPACITY'
FEETSORE = 'EVER HAD FEET SORES OR IRRITATIONS LASTING MORE THAN FOUR WEEKS'
FIREARM5 = 'ANY FIREARMS IN HOME'
FIRSTAID = 'FIRST AID FOR HEART ATTACK AND STROKE'
FLSHTMY3 = 'WHEN RECEIVED MOST RECENT SEASONAL FLU SHOT/SPRAY'
FLUSHOT7 = 'ADULT FLU SHOT/SPRAY PAST 12 MOS'
FMONTH = 'FILE MONTH'
FOODSTMP = 'DURING THE PAST 12 MONTHS HAVE YOU RECEIVED FOOD STAMPS'
GENHLTH = 'GENERAL HEALTH'
GUNLOAD = 'ANY FIREARMS LOADED'
HADHYST2 = 'HAD HYSTERECTOMY'
HADMAM = 'HAVE YOU EVER HAD A MAMMOGRAM'
HADSIGM4 = 'EVER HAD SIGMOIDOSCOPY/COLONOSCOPY'
HASYMP1 = 'HEART ATTACK SYMPTOMS - JAW/BACK/NECK PAIN'
HASYMP2 = 'HEART ATTACK SYMPTOMS - WEAK/LIGHT-HEADED/FAINT'
HASYMP3 = 'HEART ATTACK SYMPTOMS - CHEST PAIN/DISCOMFORT'
HASYMP4 = 'HEART ATTACK SYMPTOMS - VISION PROBLEMS'
HASYMP5 = 'HEART ATTACK SYMPTOMS - PAIN OR DISCOMFORT IN ARMS/SHOULDER'
HASYMP6 = 'HEART ATTACK SYMPTOMS - SHORTNESS OF BREATH'
HAVARTH4 = 'TOLD HAVE ARTHRITIS'
HEATTBCO = 'HAVE YOU HEARD OF HEATED TOBACCO PRODUCTS?'
HEIGHT3 = 'REPORTED HEIGHT IN FEET AND INCHES'
HHADULT = 'NUMBER OF ADULTS IN HOUSEHOLD'
HIVTST7 = 'EVER TESTED H.I.V.'
HIVTSTD3 = 'MONTH AND YEAR OF LAST HIV TEST'
HOWLONG = 'HOW LONG SINCE LAST MAMMOGRAM'
HPVADSHT = 'NUMBER OF HPV SHOTS RECEIVED'
HPVADVC4 = 'EVER HAD AN H.P.V. VACCINATION?'
HTIN4 = 'COMPUTED HEIGHT IN INCHES'
HTM4 = 'COMPUTED HEIGHT IN METERS'
IDATE = 'INTERVIEW DATE'
IDAY = 'INTERVIEW DAY'
IMFVPLA4 = 'WHERE DID YOU GET YOUR LAST FLU SHOT/VACCINE?'
IMONTH = 'INTERVIEW MONTH'
INCOME3 = 'INCOME LEVEL'
INDORTAN = 'TIMES USED AN INDOOR TANNING DEVICE'
INSULIN1 = 'NOW TAKING INSULIN'
IYEAR = 'INTERVIEW YEAR'
JOINPAI2 = 'HOW BAD WAS JOINT PAIN'
LADULT1 = 'ARE YOU 18 YEARS OF AGE OR OLDER?'
LANDLINE = 'DO YOU ALSO HAVE A LANDLINE TELEPHONE?'
LANDSEX2 = 'ARE YOU MALE OR FEMALE?'
LASTSIG4 = 'TIME SINCE LAST SIGMOIDOSCOPY/COLONOSCOPY'
LASTSMK2 = 'INTERVAL SINCE LAST SMOKED'
LCSCTSC1 = 'DID YOU HAVE A CT OR CAT SCAN?'
LCSCTWHN = 'WHEN DID YOU HAVE YOUR MOST RECENT CT OR CAT SCAN?'
LCSFIRST = 'HOW OLD WHEN YOU FIRST STARTED SMOKING?'
LCSLAST = 'HOW OLD WHEN YOU LAST SMOKED?'
LCSNUMCG = 'ON AVERAGE, HOW MANY CIGARETTES DO YOU SMOKE EACH DAY?'
LCSSCNCR = 'WERE ANY CT OR CAT SCANS DONE TO CHECK FOR LUNG CANCER?'
LMTJOIN3 = 'LIMITED BECAUSE OF JOINT SYMPTOMS'
LNDSXBRT = 'WHAT WAS YOUR SEX AT BIRTH?'
LOADULK2 = 'ANY LOADED FIREARMS ALSO UNLOCKED'
LSATISFY = 'SATISFACTION WITH LIFE'
MARIJAN1 = 'DURING THE PAST 30 DAYS, ON HOW MANY DAYS DID YOU USE MARIJUANA OR HASHISH?'
MARITAL = 'MARITAL STATUS'
MARJDAB = 'DID YOU DAB MARIJUANA OR CANNABIS?'
MARJEAT = 'DID YOU EAT MARIJUANA OR CANNABIS?'
MARJOTHR = 'DID YOU USE MARIJUANA OR CANNABIS SOME OTHER WAY?'
MARJSMOK = 'DID YOU SMOKE MARIJUANA OR CANNABIS?'
MARJVAPE = 'DID YOU VAPE MARIJUANA OR CANNABIS?'
MAXDRNKS = 'MOST DRINKS ON SINGLE OCCASION PAST 30 DAYS'
MAXVO21_ = 'ESTIMATED AGE-GENDER SPECIFIC MAXIMUM OXYGEN CONSUMPTION'
MEDCOST1 = 'COULD NOT AFFORD TO SEE DOCTOR'
MENTCIGS = 'DO YOU USUALLY SMOKE MENTHOL CIGARETTES?'
MENTECIG = 'DO YOU USUALLY USE MENTHOL E-CIGARETTES?'
MENTHLTH = 'NUMBER OF DAYS MENTAL HEALTH NOT GOOD'
METVL12_ = 'ACTIVITY MET VALUE FOR FIRST ACTIVITY'
METVL22_ = 'ACTIVITY MET VALUE FOR SECOND ACTIVITY'
MSCODE = 'METROPOLITAN STATUS CODE'
NUMADULT = 'NUMBER OF ADULTS IN HOUSEHOLD'
NUMBURN3 = 'NUMBER OF SUNBURNS IN PAST 12 MONTHS'
NUMHHOL4 = 'HOUSEHOLD LANDLINE TELEPHONES'
NUMPHON4 = 'RESIDENTIAL LANDLINE PHONES'
PA3MIN_ = 'MINUTES OF TOTAL PHYSICAL ACTIVITY PER WEEK'
PA3VIGM_ = 'MINUTES OF TOTAL VIGOROUS PHYSICAL ACTIVITY PER WEEK'
PADUR1_ = 'MINUTES OF FIRST ACTIVITY'
PADUR2_ = 'MINUTES OF SECOND ACTIVITY'
PAFREQ1_ = 'PHYSICAL ACTIVITY FREQUENCY PER WEEK FOR FIRST ACTIVITY'
PAFREQ2_ = 'PHYSICAL ACTIVITY FREQUENCY PER WEEK FOR SECOND ACTIVITY'
PAMIN13_ = 'MINUTES OF PHYSICAL ACTIVITY PER WEEK FOR FIRST ACTIVITY'
PAMIN23_ = 'MINUTES OF PHYSICAL ACTIVITY PER WEEK FOR SECOND ACTIVITY'
PAMISS3_ = 'MISSING PHYSICAL ACTIVITY DATA'
PAVIG13_ = 'MINUTES OF VIGOROUS PHYSICAL ACTIVITY PER WEEK FOR FIRST ACTIVITY'
PAVIG23_ = 'MINUTES OF VIGOROUSPHYSICAL ACTIVITY PER WEEK FOR SECOND ACTIVITY'
PCPSARS2 = 'WHAT WAS THE MAIN REASON YOU HAD THIS PSA TEST?'
PCSTALK2 = 'DID YOU TALK ABOUT THE ADVANTAGES OR DISADVANTAGES OF P.S.A. TEST'
PDIABTS1 = 'WHEN WAS YOUR LAST BLOOD TEST FOR HIGH BLOOD SUGAR?'
PERSDOC3 = 'HAVE PERSONAL HEALTH CARE PROVIDER?'
PHYSHLTH = 'NUMBER OF DAYS PHYSICAL HEALTH NOT GOOD'
PNEUVAC4 = 'PNEUMONIA SHOT EVER'
POORHLTH = 'POOR PHYSICAL OR MENTAL HEALTH'
PREDIAB2 = 'EVER BEEN TOLD YOU HAVE PRE-DIABETES OR BORDERLINE DIABETES'
PREGNANT = 'PREGNANCY STATUS'
PRIMINS1 = 'WHAT IS CURRENT PRIMARY SOURCE OF HEALTH INSURANCE?'
PSASUGS1 = 'WHO FIRST SUGGESTED THIS P.S.A. TEST?'
PSATEST1 = 'EVER HAD PSA TEST'
PSATIME1 = 'TIME SINCE MOST RECENT PSA TEST'
PVTRESD1 = 'PRIVATE RESIDENCE?'
PVTRESD3 = 'DO YOU LIVE IN A PRIVATE RESIDENCE?'
QSTLANG = 'LANGUAGE IDENTIFIER'
QSTVER = 'QUESTIONNAIRE VERSION IDENTIFIER'
RCSGEND1 = 'SEX OF CHILD'
RCSRLTN2 = 'RELATIONSHIP TO CHILD'
RCSXBRTH = 'CHILDS SEX AT BIRT'
RENTHOM1 = 'OWN OR RENT HOME'
RESPSLC1 = 'RESPONDENT SELECTION'
RRATWRK2 = 'HOW DO YOU FEEL YOU WERE TREATED AT WORK COMPARED TO PEOPLE OF OTHER RACES IN PAST 12 MONTHS?'
RRCLASS3 = 'HOW DO OTHER PEOPLE USUALLY CLASSIFY YOU IN THIS COUNTRY?'
RRCOGNT2 = 'HOW OFTEN DO YOU THINK ABOUT YOUR RACE?'
RRHCARE4 = 'WHEN SEEKING HEALTH CARE PAST 12 MONTHS, WAS EXPERIENCE WORSE, SAME, BETTER THAN PEOPLE OF OTHER RACES?'
RRPHYSM2 = 'TIMES PAST 30 DAYS FELT PHYSICAL SYMPTOMS BECAUSE OF TREATMENT DUE TO YOUR RACE'
RRTREAT = 'WERE YOU TREATED WORSE THAN, THE SAME, OR BETTER THAN PEOPLE OF OTHER RACES?'
SAFETIME = 'SAFE TIME TO TALK?'
SDHBILLS = 'WERE YOU NOT ABLE TO PAY YOUR BILLS?'
SDHEMPLY = 'HAVE YOU LOST EMPLOYMENT OR HAD HOURS REDUCED?'
SDHFOOD1 = 'HOW OFTEN DID THE FOOD THAT YOU BOUGHT NOT LAST, AND YOU DIDNT HAVE MONEY TO GET MORE?'
SDHSTRE1 = 'HOW OFTEN HAVE YOU FELT THIS KIND OF STRESS?'
SDHTRNSP = 'HAS A LACK OF RELIABLE TRANSPORTATION KEPT YOU FROM APPOINTMENTS, MEETINGS, WORK, OR GETTING THINGS NEEDED'
SDHUTILS = 'WERE YOU NOT ABLE TO PAY UTILITY BILLS OR THREATENED TO LOSE SERVICE?'
SDLONELY = 'HOW OFTEN DO YOU FEEL LONELY?'
SDNATES1 = 'HOW LONG SINCE YOU HAD STOOL DNA?'
SEATBELT = 'HOW OFTEN USE SEATBELTS IN CAR?'
SEQNO = 'ANNUAL SEQUENCE NUMBER'
SEXVAR = 'SEX OF RESPONDENT'
SHINGLE2 = 'HAVE YOU EVER HAD THE SHINGLES OR ZOSTER VACCINE?'
SIGMTES1 = 'HOW LONG HAS IT BEEN SINCE YOU HAD SIGMOIDOSCOPY?'
SMALSTOL = 'EVER HAD STOOL TEST?'
SMOKDAY2 = 'FREQUENCY OF DAYS NOW SMOKING'
SMOKE100 = 'SMOKED AT LEAST 100 CIGARETTES'
SOFEMALE = 'SEXUAL ORIENTATION'
SOMALE = 'SEXUAL ORIENTATION'
STATERE1 = 'RESIDENT OF STATE'
STOLTEST = 'HOW LONG SINCE YOU HAD STOOL TEST?'
STOOLDN2 = 'EVER HAD STOOL DNA TEST?'
STOPSMK2 = 'STOPPED SMOKING IN PAST 12 MONTHS'
STRENGTH = 'HOW MANY TIMES DID YOU DO PHYSICAL ACTIVITIES OR EXERCISES TO STRENGTHEN YOUR MUSCLES?'
STRFREQ_ = 'STRENGTH ACTIVITY FREQUENCY PER WEEK'
STRSYMP1 = 'STROKE SYMPTOMS - CONFUSION/TROUBLE SPEAKING'
STRSYMP2 = 'STROKE SYMPTOMS - NUMBNESS OR WEAKNESS OF FACE/ARM/LEG'
STRSYMP3 = 'STROKE SYMPTOMS - VISION PROBLEMS'
STRSYMP4 = 'STROKE SYMPTOMS - CHEST PAIN/DISCOMFORT'
STRSYMP5 = 'STROKE SYMPTOMS - TROUBLE WALKING/DIZZINESS/LOSS OF BALANCE'
STRSYMP6 = 'STROKE SYMPTOMS - SEVERE HEADACHE'
SUNPRTCT = 'HOW OFTEN PROTECT YOURSELF FROM THE SUN'
TETANUS1 = 'RECEIVED TETANUS SHOT SINCE 2005?'
TOLDHI3 = 'EVER TOLD CHOLESTEROL IS HIGH'
TRNSGNDR = 'DO YOU CONSIDER YOURSELF TO BE TRANSGENDER?'
USEMRJN4 = 'DURING THE PAST 30 DAYS, HOW DID YOU PRIMARILY USE MARIJUANA?'
USENOW3 = 'USE OF SMOKELESS TOBACCO PRODUCTS'
VCLNTES2 = 'HOW LONG HAS IT BEEN SINCE YOU HAD VIRTUAL COLONOSCOPY?'
VETERAN3 = 'ARE YOU A VETERAN'
VIRCOLO1 = 'HAVE YOU EVER HAD A VIRTUAL COLONOSCOPY?'
WEIGHT2 = 'REPORTED WEIGHT IN POUNDS'
WKDAYOUT = 'HOW OFTEN OUTSIDE ON WEEKDAYS'
WKENDOUT = 'HOW OFTEN OUTSIDE ON WEEKENDS'
WTKG3 = 'COMPUTED WEIGHT IN KILOGRAMS'
_AGE65YR = 'REPORTED AGE IN TWO AGE GROUPS CALCULATED VARIABLE'
_AGE80 = 'IMPUTED AGE VALUE COLLAPSED ABOVE 80'
_AGEG5YR = 'REPORTED AGE IN FIVE-YEAR AGE CATEGORIES CALCULATED VARIABLE'
_AGE_G = 'IMPUTED AGE IN SIX GROUPS'
_AIDTST4 = 'EVER BEEN TESTED FOR HIV CALCULATED VARIABLE'
_ASTHMS1 = 'COMPUTED ASTHMA STATUS'
_BMI5 = 'COMPUTED BODY MASS INDEX'
_BMI5CAT = 'COMPUTED BODY MASS INDEX CATEGORIES'
_CASTHM1 = 'CURRENT ASTHMA CALCULATED VARIABLE'
_CHISPNC = 'CHILD HISPANIC, LATINO/A, OR SPANISH ORIGIN CALCULATED VARIABLE'
_CHLDCNT = 'COMPUTED NUMBER OF CHILDREN IN HOUSEHOLD'
_CHOLCH3 = 'CHOLESTEROL CHECKED CALCULATED VARIABLE'
_CLLCPWT = 'FINAL CHILD WEIGHT: LAND-LINE AND CELL-PHONE DATA'
_CRACE1 = 'CHILD NON-HISPANIC RACE INCLUDING MULTIRACIAL'
_CURECI2 = 'CURRENT E-CIGARETTE USER CALCULATED VARIABLE'
_DRDXAR2 = 'RESPONDENTS DIAGNOSED WITH ARTHRITIS'
_DRNKDRV = 'DRINKING AND DRIVING'
_DRNKWK2 = 'COMPUTED NUMBER OF DRINKS OF ALCOHOL BEVERAGES PER WEEK'
_DUALCOR = 'DUAL PHONE USE CORRECTION FACTOR'
_DUALUSE = 'DUAL PHONE USE CATEGORIES'
_EDUCAG = 'COMPUTED LEVEL OF EDUCATION COMPLETED CATEGORIES'
_FLSHOT7 = 'FLU SHOT CALCULATED VARIABLE'
_HCVU653 = 'RESPONDENTS AGED 18-64 WITH HEALTH INSURANCE'
_HISPANC = 'HISPANIC, LATINO/A, OR SPANISH ORIGIN CALCULATED VARIABLE'
_HLTHPL1 = 'HAVE ANY HEALTH INSURANCE'
_IMPRACE = 'IMPUTED RACE/ETHNICITY VALUE'
_INCOMG1 = 'COMPUTED INCOME CATEGORIES'
_LLCPWT = 'FINAL WEIGHT: LAND-LINE AND CELL-PHONE DATA'
_LLCPWT2 = 'TRUNCATED DESIGN WEIGHT USED IN ADULT COMBINED LAN  LINE AND CELL PHONE RAKING'
_LTASTH1 = 'LIFETIME ASTHMA CALCULATED VARIABLE'
_MENT14D = 'COMPUTED MENTAL HEALTH STATUS'
_METSTAT = 'METROPOLITAN STATUS'
_MICHD = 'RESPONDENTS THAT HAVE EVER REPORTED HAVING CORONARY HEART DISEASE (CHD) OR MYOCARDIAL INFARCTION (MI)'
_MINAC12 = 'MINUTES OF PHYSICAL ACTIVITY PER WEEK FOR FIRST ACTIVITY'
_MINAC22 = 'MINUTES OF PHYSICAL ACTIVITY PER WEEK FOR SECOND ACTIVITY'
_MRACE1 = 'CALCULATED NON-HISPANIC RACE INCLUDING MULTIRACIAL'
_PA150R4 = '150 MINUTE PHYSICAL ACTIVITY CALCULATED VARIABLE'
_PA30023 = '300 MINUTE PHYSICAL ACTIVITY 2-LEVEL CALCULATED VARIABLE'
_PA300R4 = '300 MINUTE PHYSICAL ACTIVITY CALCULATED VARIABLE'
_PACAT3 = 'PHYSICAL ACTIVITY CATEGORIES'
_PAINDX3 = 'PHYSICAL ACTIVITY INDEX'
_PAREC3 = 'AEROBIC AND STRENGTHENING GUIDELINE'
_PASTAE3 = 'AEROBIC AND STRENGTHENING (2-LEVEL)'
_PASTRNG = 'MUSCLE STRENGTHENING RECOMMENDATION'
_PHYS14D = 'COMPUTED PHYSICAL HEALTH STATUS'
_PNEUMO3 = 'PNEUMONIA VACCINATION CALCULATED VARIABLE'
_PSU = 'PRIMARY SAMPLING UNIT'
_RACE = 'COMPUTED RACE-ETHNICITY GROUPING'
_RACEG21 = 'COMPUTED NON-HISPANIC WHITES/ALL OTHERS RACE CATEGORIES RACE/ETHNIC GROUP CODES USED IN POST-STRATIFICATION.'
_RACEGR3 = 'COMPUTED FIVE LEVEL RACE/ETHNICITY CATEGORY.'
_RACEPRV = 'COMPUTED RACE GROUPS USED FOR INTERNET PREVALENCE TABLES'
_RAWRAKE = 'RAW WEIGHTING FACTOR USED IN RAKING'
_RFBING6 = 'BINGE DRINKING CALCULATED VARIABLE'
_RFBMI5 = 'OVERWEIGHT OR OBESE CALCULATED VARIABLE'
_RFCHOL3 = 'HIGH CHOLESTEROL CALCULATED VARIABLE'
_RFDRHV8 = 'HEAVY ALCOHOL CONSUMPTION  CALCULATED VARIABLE'
_RFHLTH = 'ADULTS WITH GOOD OR BETTER HEALTH'
_RFHYPE6 = 'HIGH BLOOD PRESSURE CALCULATED VARIABLE'
_RFSEAT2 = 'ALWAYS OR NEARLY ALWAYS WEAR SEAT BELTS'
_RFSEAT3 = 'ALWAYS WEAR SEAT BELTS'
_RFSMOK3 = 'CURRENT SMOKING CALCULATED VARIABLE'
_SEX = 'CALCULATED SEX VARIABLE'
_SMOKER3 = 'COMPUTED SMOKING STATUS'
_STATE = 'STATE FIPS CODE'
_STRWT = 'STRATUM WEIGHT'
_STSTR = 'SAMPLE DESIGN STRATIFICATION VARIABLE'
_TOTINDA = 'LEISURE TIME PHYSICAL ACTIVITY CALCULATED VARIABLE'
_URBSTAT = 'URBAN/RURAL STATUS'
_WT2RAKE = 'DESIGN WEIGHT USED IN RAKING'
;
RUN;
